@@ -2,7 +2,6 @@ use strict;
 use warnings;
 use Alien::FLTK;
 use ExtUtils::CBuilder;
-my $AF     = Alien::FLTK->new();
 my $CC     = ExtUtils::CBuilder->new();
 my $source = 'gl_hello_world.cxx';
 open(my $FH, '>', $source) || die '...';
@@ -65,11 +64,11 @@ int main( int argc, char **argv ) {
 }
 
 my $obj = $CC->compile(source               => $source,
-                       include_dirs         => [$AF->include_dirs()],
-                       extra_compiler_flags => $AF->cxxflags()
+                       extra_compiler_flags => Alien::FLTK->cxxflags());
+my $exe = $CC->link_executable(
+                          objects            => $obj,
+                          extra_linker_flags => [Alien::FLTK->ldflags(qw[gl])]
 );
-my $exe = $CC->link_executable(objects            => $obj,
-                               extra_linker_flags => [$AF->ldflags(qw[gl])]);
 printf system('./' . $exe) ? 'Aww...' : 'Yay! %s bytes', -s $exe;
 END { unlink grep defined, $source, $obj, $exe; }
 
@@ -95,6 +94,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: 0002_gl.pl 84504b8 2009-10-27 21:17:03Z sanko@cpan.org $
+=for git $Id: 0002_gl.pl 1d4b8d3 2009-10-03 23:51:59Z sanko@cpan.org $
 
 =cut
