@@ -1,18 +1,19 @@
-package inc::MBX::Alien::FLTK;
+package MBX::Alien::FLTK;
 {
     use strict;
     use warnings;
     use Config qw[%Config];
     use Module::Build;
-    use lib '../';
-    use base 'inc::MBX::Alien::FLTK::Base';
+    use lib '../..';
+    use base 'MBX::Alien::FLTK::Base';
     use vars qw[@ISA];
 
     sub new {
         my ($class, %args) = @_;
         shift;
-        my $OS = $args{'osname'} || $Config{'osname'} || $^O;
-        my $CC = $args{'cc'}     || $Config{'ccname'} || $Config{'cc'};
+        my $self     = $class->SUPER::new(@_);
+        my $OS       = $args{'osname'} || $Config{'osname'} || $^O;
+        my $CC       = $args{'cc'} || $Config{'ccname'} || $Config{'cc'};
         my @platform = grep defined, $OS =~ m[Win32]
             ? (
             'Windows',
@@ -24,44 +25,38 @@ package inc::MBX::Alien::FLTK;
              : ()                              # Hope for the best
             )
             )
-            : $OS =~ m[CygWin]i ? (qw[Windows CygWin])    # ...baka
-            : (
-            'Unix',
-            ($OS =~ m[Darwin]i
-             ? 'Darwin'                                   # Mac OSX
-             : $OS =~ m[BSD$]i    ? 'BSD'
-             : $OS =~ m[Solaris]i ? 'Solaris'
-             : $OS =~ m[IRIX]i    ? 'IRIX'
-             : ()
-            )
-            );
-        my $platform = 'inc::MBX::Alien::FLTK::Platform';
+            : $OS =~ m[CygWin]i ? ('Windows', 'CygWin')    # ...baka
+            : $OS =~ m[Darwin]i  ? 'Darwin'     # Mac OSX
+            : $OS =~ m[BSD$]i    ? 'BSD'        # requires GNUmake (gmake)
+            : $OS =~ m[Solaris]i ? 'Solaris'    # requires GNUmake (gmake)
+            : $OS =~ m[IRIX]i    ? 'IRIX'       # requires GNUmake (gmake)
+            :                      'Unix';
+        my $platform = 'MBX::Alien::FLTK::Platform';
         for my $qual (@platform) {
             $platform .= '::' . $qual;
-            eval "require $platform";
+            eval "use $platform";
             next if $@;
             unshift @ISA, $platform;
         }
-        my $self = $class->SUPER::new(@_);
         $self->notes(platform => \@platform);
         $self->notes(os       => $OS);
         $self->notes(cc       => $CC);
-        $self->notes(errors   => []);
         return $self;
     }
 
     sub resume {
         my $self      = shift->SUPER::resume(@_);
         my $platform  = $self->notes('platform');
-        my $_platform = 'inc::MBX::Alien::FLTK::Platform';
+        my $_platform = 'MBX::Alien::FLTK::Platform';
         for my $qual (@$platform) {
             $_platform .= '::' . $qual;
-            eval "require $_platform";
+            eval "use $_platform";
             next if $@;
             unshift @ISA, $_platform;
         }
         return $self;
     }
+    sub VERBOSE { !shift->quiet() }
     1;
 }
 
@@ -87,6 +82,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: FLTK.pm dfa6aa4 2010-01-16 21:12:51Z sanko@cpan.org $
+=for git $Id: FLTK.pm 2fbc10d 2009-09-18 03:50:45Z sanko@cpan.org $
 
 =cut
